@@ -1,4 +1,4 @@
-#    $Id: Nominet.pm,v 1.18 2017/09/05 14:25:02 pete Exp $
+#    $Id: Nominet.pm,v 1.21 2019/03/18 14:58:27 pete Exp $
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ use constant EPP_XMLNS	=> 'urn:ietf:params:xml:ns:epp-1.0';
 use vars qw($Error $Code $Message);
 
 BEGIN {
-	our $VERSION = '0.03_01';
+	our $VERSION = '0.03_02';
 }
 
 # file-scoped lexicals
@@ -166,10 +166,14 @@ sub new {
 		$params{host} = $Host;
 	}
 	$params{timeout}	= (int($params{timeout} || 0) > 0 ? $params{timeout} : 5);
-	if ($params{ssl} and $params{verify}) {
-		$params{SSL_ca_file}      ||= $params{ca_file};
-		$params{SSL_ca_path}      ||= $params{ca_path};
-		$params{SSL_verify_mode}  =   0x01;
+	if ($params{ssl}) {
+		if ($params{verify}) {
+			$params{SSL_ca_file}      ||= $params{ca_file};
+			$params{SSL_ca_path}      ||= $params{ca_path};
+			$params{SSL_verify_mode}  =   0x01;
+		} else {
+			$params{SSL_verify_mode}  =   0x00;
+		}
 	}
 	if ($params{ssl} and $params{ciphers}) {
 		$params{SSL_cipher_list} = $params{ciphers};
@@ -1053,6 +1057,21 @@ sub modify_contact {
 		$elem->appendText ($data->{$field});
 		$chg->appendChild ($elem);
 	}
+	if (defined $data->{disclose}) {
+		my $add = $frame->createElement ('contact:disclose');
+		$add->setAttribute('flag', '1');
+		my $del = $frame->createElement ('contact:disclose');
+		$del->setAttribute('flag', '0');
+		for my $field (qw/org addr/) {
+			next unless defined $data->{disclose}->{$field};
+			my $disc = $frame->createElement ("contact:$field");
+			$disc->setAttribute('type', 'loc');
+			($data->{disclose}->{$field} ? $add : $del)->appendChild ($disc);
+		}
+		for my $child ($add, $del) {
+			$chg->appendChild ($child) if $child->hasChildNodes;
+		}
+	}
 	if ($chg->hasChildNodes) { $obj->appendChild($chg); }
 
 	# Extensions
@@ -1185,11 +1204,13 @@ sub _info {
 		my $extra2 = $response->getNode('secDNS:infData');
 		return $self->_domain_infData_to_hash($infData, $extra);
 	} elsif ($type eq 'contact') {
+		# Grab disclose infdata before Net::EPP::Simple deletes it
+		my $disclose = $self->_disclose_infData_to_hash ($infData);
 		$self->_clean_addr($infData);
 		my $this = $self->_contact_infData_to_hash($infData);
 		# Add in the Nominet extras (reg, rather than contact)
 		my $extra = $response->getNode('contact-nom-ext:infData');
-		return $self->_merge_contact_infData ($this, $extra);
+		return $self->_merge_contact_infData ($this, $extra, $disclose);
 	} elsif ($type eq 'host') {
 		return $self->_host_infData_to_hash($infData);
 	}
@@ -1217,6 +1238,20 @@ sub _domain_infData_to_hash {
 	return $hash;
 }
 
+sub _disclose_infData_to_hash {
+	my ($self, $infData) = @_;
+	my $disc = $infData->getElementsByLocalName('disclose')->shift;
+	return unless $disc;
+	my $flag = $disc->getAttribute('flag');
+	my $hash;
+	for my $child ($disc->getChildrenByTagName('*')) {
+		$hash->{$child->localname} = {
+			flag => $flag,
+		};
+	}
+	return $hash;
+}
+
 sub _tag_infData_to_hash {
 	my ($self, $infData) = @_;
 	return $self->_node_to_hash ($infData, ['registrar-tag',
@@ -1236,7 +1271,7 @@ sub _clean_addr {
 }
 
 sub _merge_contact_infData {
-	my ($self, $old, $extra) = @_;
+	my ($self, $old, $extra, $disclose) = @_;
 
 	my $extrahash = $self->_node_to_hash ($extra, ['type',
 	'co-no', 'opt-out', 'trad-name']);
@@ -1244,6 +1279,7 @@ sub _merge_contact_infData {
 	for (keys %$extrahash) {
 		$old->{$_} = $extrahash->{$_};
 	}
+	$old->{disclose} = $disclose;
 	return $old;
 
 }
@@ -1576,6 +1612,19 @@ sub set_reason {
 	return $self->{'_reason'};
 }
 
+sub get_debug {
+	my $self = shift;
+	return $self->{debug};
+}
+
+sub set_debug {
+	my ($self, $debug) = @_;
+	croak "Debug must be whole number" unless $debug =~ /^\d+$/;
+	$Debug = $debug;
+	$self->{debug} = $Debug > 1 ? 1 : 0; # for parent
+	return $Debug;
+}
+
 sub _send_frame {
 	my ($self, $frame) = @_;
 
